@@ -1,17 +1,10 @@
 
-use 5;
+package DateTime::Format::Atom;
 
 use strict;
 use warnings;
 
-
-package DateTime::Format::Atom;
-
-
-BEGIN {
-   use version; our $VERSION = qv('1.0.1');
-}
-
+use version; our $VERSION = qv('v1.2.0');
 
 use DateTime::Format::RFC3339 qw( );
 
@@ -63,7 +56,7 @@ DateTime::Format::Atom - Parse and format Atom datetime strings
 
 =head1 VERSION
 
-Version 1.0.1
+Version 1.2.0
 
 
 =head1 SYNOPSIS
@@ -82,7 +75,7 @@ Version 1.0.1
 This module understands the Atom date/time format, an ISO 8601 profile, defined
 at L<http://tools.ietf.org/html/rfc4287>
 
-It can be used to parse these formats in order to create the appropriate 
+It can be used to parse these formats in order to create the appropriate
 objects.
 
 All the work is actually done by L<DateTime::Format::RFC3339>.
@@ -130,7 +123,7 @@ For simplicity, the datetime will be converted to UTC first.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-datetime-format-atom at rt.cpan.org>,
+Please report any bugs or feature requests to C<bug-Datetime-Format-Atom at rt.cpan.org>,
 or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DateTime-Format-Atom>.
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
@@ -171,7 +164,15 @@ Eric Brine, C<< <ikegami@adaelis.com> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Public domain. No rights reserved.
+No rights reserved.
+
+The author has dedicated the work to the Commons by waiving all of his
+or her rights to the work worldwide under copyright law and all related or
+neighboring legal rights he or she had in the work, to the extent allowable by
+law.
+
+Works under CC0 do not require attribution. When citing the work, you should
+not imply endorsement by the author.
 
 
 =cut
